@@ -8,7 +8,10 @@ from flyingsphinx import Configuration
 @fudge.test
 def test_configuration_upload():
   api = fudge.Fake('API')
-  api.expects('put').with_args('/', {'configuration': 'provided content'})
+  api.expects('put').with_args('/', {
+    'configuration': 'provided content',
+    'sphinx_version': '2.0.4'
+  })
   Configuration(api).upload('provided content')
 
 @fudge.patch('__builtin__.open')
@@ -18,7 +21,10 @@ def test_configuration_upload_from_file(fake_open):
   fake_open.is_callable().calls(lambda path: conf_file)
   conf_file.provides('read').returns('content in file')
 
-  api.expects('put').with_args('/', {'configuration': 'content in file'})
+  api.expects('put').with_args('/', {
+    'configuration': 'content in file',
+    'sphinx_version': '2.0.4'
+  })
 
   Configuration(api).upload_from_file('/path/to/file')
 
